@@ -1,5 +1,5 @@
 #
-# $Id: Base64.pm,v 2.35 2004/01/08 13:16:33 gisle Exp $
+# $Id: Base64.pm,v 2.37 2004/01/08 14:07:26 gisle Exp $
 
 package MIME::Base64;
 
@@ -16,9 +16,9 @@ MIME::Base64 - Encoding and decoding of base64 strings
 
 =head1 DESCRIPTION
 
-This module provides functions to encode and decode strings into the
-Base64 encoding specified in RFC 2045 - I<MIME (Multipurpose Internet
-Mail Extensions)>. The Base64 encoding is designed to represent
+This module provides functions to encode and decode strings into and from the
+base64 encoding specified in RFC 2045 - I<MIME (Multipurpose Internet
+Mail Extensions)>. The base64 encoding is designed to represent
 arbitrary sequences of octets in a form that need not be humanly
 readable. A 65-character subset ([A-Za-z0-9+/=]) of US-ASCII is used,
 enabling 6 bits to be represented per printable character.
@@ -32,12 +32,12 @@ The following functions are provided:
 =item encode_base64($str, $eol);
 
 Encode data by calling the encode_base64() function.  The first
-argument is the string to encode.  The second argument is the line
-ending sequence to use.  It is optional and defaults to "\n".  The
+argument is the string to encode.  The second argument is the
+line-ending sequence to use.  It is optional and defaults to "\n".  The
 returned encoded string is broken into lines of no more than 76
 characters each and it will end with $eol unless it is empty.  Pass an
 empty string as second argument if you do not want the encoded string
-broken into lines.
+to be broken into lines.
 
 =item decode_base64($str)
 
@@ -45,17 +45,17 @@ Decode a base64 string by calling the decode_base64() function.  This
 function takes a single argument which is the string to decode and
 returns the decoded data.
 
-Any character not part of the 65-character base64 subset set is
-silently ignored.  Characters occuring after a '=' padding character
+Any character not part of the 65-character base64 subset is
+silently ignored.  Characters occurring after a '=' padding character
 are never decoded.
 
 If the length of the string to decode, after ignoring
-non-base64 chars, is not a multiple of 4 or padding occurs too early,
+non-base64 chars, is not a multiple of 4 or if padding occurs too early,
 then a warning is generated if perl is running under C<-w>.
 
 =back
 
-If you prefer not to import these routines into your namespace you can
+If you prefer not to import these routines into your namespace, you can
 call them as:
 
     use MIME::Base64 ();
@@ -64,7 +64,7 @@ call them as:
 
 =head1 DIAGNOSTICS
 
-The following warnings might be generated if perl is invoked with the
+The following warnings can be generated if perl is invoked with the
 C<-w> switch:
 
 =over 4
@@ -107,14 +107,14 @@ The same approach as a command line:
 
    perl -MMIME::Base64 -0777 -ne 'print encode_base64($_)' <file
 
-Decoding does not need slurp mode if all the lines contains a multiple
-of 4 base64 chars:
+Decoding does not need slurp mode if every line contains a multiple
+of four base64 chars:
 
    perl -MMIME::Base64 -ne 'print decode_base64($_)' <file
 
 =head1 COPYRIGHT
 
-Copyright 1995-1999, 2001-2003 Gisle Aas.
+Copyright 1995-1999, 2001-2004 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -124,7 +124,7 @@ Distantly based on LWP::Base64 written by Martijn Koster
 code posted to comp.lang.perl <3pd2lp$6gf@wsinti07.win.tue.nl> by Hans
 Mulder <hansm@wsinti07.win.tue.nl>
 
-The XS implementation use code from metamail.  Copyright 1991 Bell
+The XS implementation uses code from metamail.  Copyright 1991 Bell
 Communications Research, Inc. (Bellcore)
 
 =head1 SEE ALSO
@@ -141,7 +141,7 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 @EXPORT = qw(encode_base64 decode_base64);
 
-$VERSION = '2.22';
+$VERSION = '2.23';
 
 eval { bootstrap MIME::Base64 $VERSION; };
 if ($@) {
