@@ -1,5 +1,5 @@
 #
-# $Id: QuotedPrint.pm,v 2.12 2003/05/13 16:21:25 gisle Exp $
+# $Id: QuotedPrint.pm,v 2.19 2004/01/08 14:07:26 gisle Exp $
 
 package MIME::QuotedPrint;
 
@@ -16,12 +16,12 @@ MIME::QuotedPrint - Encoding and decoding of quoted-printable strings
 
 =head1 DESCRIPTION
 
-This module provides functions to encode and decode strings into the
-Quoted-Printable encoding specified in RFC 2045 - I<MIME (Multipurpose
-Internet Mail Extensions)>.  The Quoted-Printable encoding is intended
+This module provides functions to encode and decode strings into and from the
+quoted-printable encoding specified in RFC 2045 - I<MIME (Multipurpose
+Internet Mail Extensions)>.  The quoted-printable encoding is intended
 to represent data that largely consists of bytes that correspond to
-printable characters in the ASCII character set.  Non-printable
-characters (as defined by english americans) are represented by a
+printable characters in the ASCII character set.  Each non-printable
+character (as defined by English Americans) is represented by a
 triplet consisting of the character "=" followed by two hexadecimal
 digits.
 
@@ -33,32 +33,58 @@ The following functions are provided:
 
 =item encode_qp($str, $eol)
 
-This function will return an encoded version of the string given as
-argument.  The second argument is the line ending sequence to use (it
-is optional and defaults to C<"\n">).
+This function returns an encoded version of the string given as
+argument.
+
+The second argument is the line-ending sequence to use.  It is
+optional and defaults to "\n".  Every occurrence of "\n" is
+replaced with this string, and it is also used for additional
+"soft line breaks" to ensure that no line is longer than 76
+characters.  You might want to pass it as "\015\012" to produce data
+suitable for external consumption.  The string "\r\n" produces the
+same result on many platforms, but not all.
+
+An $eol of "" (the empty string) is special.  In this case, no "soft line breaks" are introduced
+and any literal "\n" in the original data is encoded as well.
 
 =item decode_qp($str);
 
-This function will return the plain text version of the string given
-as argument.  Lines with be "\n" terminated.
+This function returns the plain text version of the string given
+as argument.  The lines of the result are "\n" terminated, even if
+the $str argument contains "\r\n" terminated lines.
 
 =back
 
 
-If you prefer not to import these routines into your namespace you can
+If you prefer not to import these routines into your namespace, you can
 call them as:
 
   use MIME::QuotedPrint ();
   $encoded = MIME::QuotedPrint::encode($decoded);
   $decoded = MIME::QuotedPrint::decode($encoded);
 
+Perl v5.6 and better allow extended Unicode characters in strings.
+Such strings cannot be encoded directly, as the quoted-printable
+encoding is only defined for single-byte characters.  The solution is to use the Encode
+module to select the byte encoding you want.  For example:
+
+    use MIME::QuotedPrint qw(encode_qp);
+    use Encode qw(encode);
+
+    $encoded = encode_qp(encode("UTF-8", "\x{FFFF}\n"));
+    print $encoded;
+
 =head1 COPYRIGHT
 
-Copyright 1995-1997,2002-2003 Gisle Aas.
+Copyright 1995-1997,2002-2004 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+L<MIME::Base64>
+
 =cut
 
 use strict;
@@ -71,9 +97,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(encode_qp decode_qp);
 
-use Carp qw(croak);
-
-$VERSION = "2.19";
+$VERSION = "2.21";
 
 use MIME::Base64;  # try to load XS version of encode_qp
 unless (defined &encode_qp) {
@@ -87,13 +111,15 @@ sub old_encode_qp ($;$)
     if ($] >= 5.006) {
 	require bytes;
 	if (bytes::length($res) > length($res) ||
-	    ($] >= 5.008 && $res =~ /[^\0-\xFF]/)) {
-	    croak("The Quoted-Printable encoding is only defined for bytes");
+	    ($] >= 5.008 && $res =~ /[^\0-\xFF]/))
+	{
+	    require Carp;
+	    Carp::croak("The Quoted-Printable encoding is only defined for bytes");
 	}
     }
 
     my $eol = shift;
-    $eol = "\n" unless defined($eol) || length($eol);
+    $eol = "\n" unless defined $eol;
 
     # Do not mention ranges such as $res =~ s/([^ \t\n!-<>-~])/sprintf("=%02X", ord($1))/eg;
     # since that will not even compile on an EBCDIC machine (where ord('!') > ord('<')).
@@ -122,12 +148,15 @@ sub old_encode_qp ($;$)
     }
     else { # ASCII style machine
         $res =~  s/([^ \t\n!"#\$%&'()*+,\-.\/0-9:;<>?\@A-Z[\\\]^_`a-z{|}~])/sprintf("=%02X", ord($1))/eg;  # rule #2,#3
+	$res =~ s/\n/=0A/g unless length($eol);
         $res =~ s/([ \t]+)$/
           join('', map { sprintf("=%02X", ord($_)) }
     		   split('', $1)
           )/egm;                        # rule #3 (encode whitespace at eol)
     }
 
+    return $res unless length($eol);
+
     # rule #5 (lines must be shorter than 76 chars, but we are not allowed
     # to break =XX escapes.  This makes things complicated :-( )
     my $brokenlines = "";
@@ -137,6 +166,7 @@ sub old_encode_qp ($;$)
 		|[^=\n]    (?! [^=\n]{0,2} $) # 74 not followed by .?.?\n
 		|          (?! [^=\n]{0,3} $) # 73 not followed by .?.?.?\n
 	    ))//xsm;
+    $res =~ s/\n\z/$eol/;
 
     "$brokenlines$res";
 }
